@@ -5,9 +5,10 @@ import shutil
 from pathlib import Path
 
 from steinbock import io
-from steinbock._env import ilastik_binary
 from steinbock.classification import ilastik
 
+ilastik_binary = "/opt/ilastik/run_ilastik.sh"
+
 
 class TestIlastikClassification:
     def test_list_ilastik_image_files(
